@@ -2,7 +2,7 @@
 (* prime.ml - Generate prime using miller-rabin primality test         *)
 (*                                                                     *)
 (* Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, *)
-(*               2011, 2012  Yaron Minsky and Contributors             *)
+(*               2011, 2012, 2013  Yaron Minsky and Contributors       *)
 (*                                                                     *)
 (* This file is part of SKS.  SKS is free software; you can            *)
 (* redistribute it and/or modify it under the terms of the GNU General *)
@@ -87,7 +87,7 @@ let miller_rabin rfunc n t =
   let test () =
     let a = randrange rfunc two (n -! one) in
     let y = Number.powmod a r n in
-    if y =! one or y =! neg_one then Prime
+    if y =! one || y =! neg_one then Prime
     else
       let rec loop y j =
         if y =! neg_one then Prime
